"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.destroy = exports.dispose = exports.create = exports.default = void 0;

var _rdsdataservice = _interopRequireDefault(require("aws-sdk/clients/rdsdataservice"));

var _resolveReadmodelBase = _interopRequireDefault(require("resolve-readmodel-base"));

var _crypto = _interopRequireDefault(require("crypto"));

var _beginXaTransaction = _interopRequireDefault(require("./begin-xa-transaction"));

var _beginEvent = _interopRequireDefault(require("./begin-event"));

var _beginTransaction = _interopRequireDefault(require("./begin-transaction"));

var _buildUpsertDocument = _interopRequireDefault(require("./build-upsert-document"));

var _commitXaTransaction = _interopRequireDefault(require("./commit-xa-transaction"));

var _commitEvent = _interopRequireDefault(require("./commit-event"));

var _commitTransaction = _interopRequireDefault(require("./commit-transaction"));

var _coercer = _interopRequireDefault(require("./coercer"));

var _connect2 = _interopRequireDefault(require("./connect"));

var _convertResultRow = _interopRequireDefault(require("./convert-result-row"));

var _count = _interopRequireDefault(require("./count"));

var _defineTable = _interopRequireDefault(require("./define-table"));

var _delete = _interopRequireDefault(require("./delete"));

var _disconnect = _interopRequireDefault(require("./disconnect"));

var _dropReadModel = _interopRequireDefault(require("./drop-read-model"));

var _escapeId = _interopRequireDefault(require("./escape-id"));

var _escape = _interopRequireDefault(require("./escape"));

var _executeStatement = _interopRequireDefault(require("./execute-statement"));

var _findOne = _interopRequireDefault(require("./find-one"));

var _find = _interopRequireDefault(require("./find"));

var _insert = _interopRequireDefault(require("./insert"));

var _rollbackXaTransaction = _interopRequireDefault(require("./rollback-xa-transaction"));

var _rollbackEvent = _interopRequireDefault(require("./rollback-event"));

var _rollbackTransaction = _interopRequireDefault(require("./rollback-transaction"));

var _searchToWhereExpression = _interopRequireDefault(require("./search-to-where-expression"));

var _updateToSetExpression = _interopRequireDefault(require("./update-to-set-expression"));

var _update = _interopRequireDefault(require("./update"));

var _generateGuid = _interopRequireDefault(require("./generate-guid"));

var _create = _interopRequireDefault(require("./resource/create"));

var _dispose = _interopRequireDefault(require("./resource/dispose"));

var _destroy = _interopRequireDefault(require("./resource/destroy"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const store = {
  defineTable: _defineTable.default,
  find: _find.default,
  findOne: _findOne.default,
  count: _count.default,
  insert: _insert.default,
  update: _update.default,
  delete: _delete.default
};

const connect = _connect2.default.bind(null, {
  RDSDataService: _rdsdataservice.default,
  escapeId: _escapeId.default,
  escape: _escape.default,
  buildUpsertDocument: _buildUpsertDocument.default,
  convertResultRow: _convertResultRow.default,
  searchToWhereExpression: _searchToWhereExpression.default,
  updateToSetExpression: _updateToSetExpression.default,
  executeStatement: _executeStatement.default,
  coercer: _coercer.default,
  generateGuid: _generateGuid.default,
  crypto: _crypto.default,
  ...store
});

const createAdapter = _resolveReadmodelBase.default.bind(null, { ...store,
  connect,
  beginTransaction: _beginTransaction.default,
  commitTransaction: _commitTransaction.default,
  rollbackTransaction: _rollbackTransaction.default,
  beginXATransaction: _beginXaTransaction.default,
  commitXATransaction: _commitXaTransaction.default,
  rollbackXATransaction: _rollbackXaTransaction.default,
  beginEvent: _beginEvent.default,
  commitEvent: _commitEvent.default,
  rollbackEvent: _rollbackEvent.default,
  dropReadModel: _dropReadModel.default,
  disconnect: _disconnect.default
});

var _default = createAdapter;
exports.default = _default;
const pool = {
  connect,
  disconnect: _disconnect.default,
  escapeId: _escapeId.default,
  escape: _escape.default
};

const createResource = _create.default.bind(null, pool);

exports.create = createResource;

const disposeResource = _dispose.default.bind(null, pool);

exports.dispose = disposeResource;

const destroyResource = _destroy.default.bind(null, pool);

exports.destroy = destroyResource;
Object.assign(pool, {
  createResource,
  disposeResource,
  destroyResource
});
//# sourceMappingURL=index.js.map